# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.131
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client_legacy.models.aggregated_nominations import AggregatedNominations  # noqa: E501

class TestAggregatedNominations(unittest.TestCase):
    """AggregatedNominations unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AggregatedNominations:
        """Test AggregatedNominations
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AggregatedNominations`
        """
        model = AggregatedNominations()  # noqa: E501
        if include_optional:
            return AggregatedNominations(
                mpn = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                gb = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                fr = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], )
            )
        else:
            return AggregatedNominations(
                mpn = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                gb = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
                fr = helix_platform_api_public_client_legacy.models.aggregated_nominations_values.AggregatedNominationsValues(
                    mtu_size = 'MTU_15_MINS', 
                    mtus = [
                        helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus.AggregatedNominationsValues_mtus(
                            mtu = '2022-01-04T10:00Z', 
                            values = [
                                helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_values.AggregatedNominationsValues_mtus_values(
                                    direction = 'GB_FR', 
                                    value = 56, )
                                ], 
                            netted_nominations = helix_platform_api_public_client_legacy.models.aggregated_nominations_values_mtus_netted_nominations.AggregatedNominationsValues_mtus_nettedNominations(
                                direction = 'GB_FR', 
                                flow = 56, ), )
                        ], ),
        )
        """

    def testAggregatedNominations(self):
        """Test AggregatedNominations"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
