# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.131
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, conlist
from helix_platform_api_public_client_legacy.models.border_direction import BorderDirection

class ParticipantDashboardNominationOptionsTimescale(BaseModel):
    """
    ParticipantDashboardNominationOptionsTimescale
    """
    delivery_days: conlist(date) = Field(default=..., alias="deliveryDays")
    available: StrictBool = Field(...)
    tr_directions: Optional[conlist(BorderDirection)] = Field(default=None, alias="trDirections")
    __properties = ["deliveryDays", "available", "trDirections"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantDashboardNominationOptionsTimescale:
        """Create an instance of ParticipantDashboardNominationOptionsTimescale from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantDashboardNominationOptionsTimescale:
        """Create an instance of ParticipantDashboardNominationOptionsTimescale from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantDashboardNominationOptionsTimescale.parse_obj(obj)

        _obj = ParticipantDashboardNominationOptionsTimescale.parse_obj({
            "delivery_days": obj.get("deliveryDays"),
            "available": obj.get("available"),
            "tr_directions": obj.get("trDirections")
        })
        return _obj


