# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.131
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client_legacy.models.default_nomination_batch import DefaultNominationBatch  # noqa: E501

class TestDefaultNominationBatch(unittest.TestCase):
    """DefaultNominationBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DefaultNominationBatch:
        """Test DefaultNominationBatch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DefaultNominationBatch`
        """
        model = DefaultNominationBatch()  # noqa: E501
        if include_optional:
            return DefaultNominationBatch(
                entries = [
                    helix_platform_api_public_client_legacy.models.default_nomination.DefaultNomination(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        timescale = 'LONG_TERM', 
                        delivery_period_start = 'Tue Jan 04 00:00:00 UTC 2022', 
                        delivery_period_end = 'Tue Jan 04 00:00:00 UTC 2022', 
                        border_direction = 'GB_FR', 
                        status = 'ACTIVE', )
                    ],
                total_count = 0
            )
        else:
            return DefaultNominationBatch(
                entries = [
                    helix_platform_api_public_client_legacy.models.default_nomination.DefaultNomination(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        timescale = 'LONG_TERM', 
                        delivery_period_start = 'Tue Jan 04 00:00:00 UTC 2022', 
                        delivery_period_end = 'Tue Jan 04 00:00:00 UTC 2022', 
                        border_direction = 'GB_FR', 
                        status = 'ACTIVE', )
                    ],
                total_count = 0,
        )
        """

    def testDefaultNominationBatch(self):
        """Test DefaultNominationBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
